==> nextcloud-18.0.4.tgz: nextcloud/apps/accessibility/l10n/lt_LT.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Tamsus apipavidalinimas",
    "Enable dark theme" : "Įjungti tamsų apipavidalinimą",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tamsus apipavidalinimas, skirtas nuraminti jūsų akis, sumažinant bendrą šviesingumą ir skaistį. Jis yra vis dar kuriamas, todėl prašome pranešti apie bet kokias randamas klaidas.",
    "High contrast mode" : "Didelio kontrasto veiksena",
    "Enable high contrast mode" : "Įjungti didelio kontrasto veikseną",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Didelio kontrasto veiksena, skirta palengvinti jūsų naršymą. Vaizdinė kokybė bus sumažinta, tačiau aiškumas bus padidintas.",
    "Dyslexia font" : "Disleksijos šriftas",
    "Enable dyslexia font" : "Įjungti disleksijos šriftą",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic yra laisvas šriftas, sukurtas sumažinti kai kurias dažniausias disleksijos sukeltas skaitymo klaidas.",
    "Accessibility" : "Prieinamumas",
    "Accessibility options for nextcloud" : "Nextcloud prieinamumo parinktys",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Pateikia kelias prieinamumo parinktis, skirtas palengvinti jūsų naudojimąsi Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Mums universalioji prieiga yra labai svarbi. Mes sekame saityno standartus ir stengiamės, kad viskuo galima būtų praktiškai pasinaudoti be pelės ir pagalbinės programinės įrangos, tokios kaip ekrano skaitytuvė. Stengiamės atitikti {guidelines}Saityno turinio prieinamumo gairėms{linkend} 2.1 pagal AA lygmenį, o su didelio kontrasto apipavidalinimu netgi pagal AAA lygmenį.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Jei rasite kokių nors problemų, nesivaržykite apie jas pranešti {issuetracker}mūsų klaidų sekiklyje{linkend}. O jei norite įsitraukti, prisijunkite prie {designteam}mūsų dizaino komandos{linkend}!",
    "High contrast theme" : "Didelio kontrasto apipavidalinimas",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Didelio kontrasto apipavidalinimas, skirtas palengvinti jūsų naršymą. Vaizdinė kokybė bus sumažinta, tačiau aiškumas bus padidintas.",
    "Dark theme (beta)" : "Tamsus apipavidalinimas (beta)",
    "Web Content Accessibility Guidelines" : "Saityno turinio prieinamumo gairėms",
    "our issue tracker" : "mūsų klaidų sekiklyje",
    "our design team" : "mūsų dizaino komandos",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines} 2.1 on AA level, with the high contrast theme even on AAA level." : "Mums universalioji prieiga yra labai svarbi. Mes sekame saityno standartus ir stengiamės, kad viskuo galima būtų praktiškai pasinaudoti be pelės ir pagalbinės programinės įrangos, tokios kaip ekrano skaitytuvė. Stengiamės atitikti {guidelines} 2.1 pagal AA lygmenį, o su didelio kontrasto apipavidalinimu netgi pagal AAA lygmenį.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}. And if you want to get involved, come join {designteam}!" : "Jei rasite kokių nors problemų, nesivaržykite apie jas pranešti {issuetracker}. O jei norite įsitraukti, prisijunkite prie {designteam}!",
    "Enable" : "Įjungti"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-18.0.6.tgz: nextcloud/apps/accessibility/l10n/lt_LT.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Tamsus apipavidalinimas",
    "Enable dark theme" : "Įjungti tamsų apipavidalinimą",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tamsus apipavidalinimas, skirtas nuraminti jūsų akis, sumažinant bendrą šviesingumą ir skaistį. Jis yra vis dar kuriamas, todėl prašome pranešti apie bet kokias randamas klaidas.",
    "High contrast mode" : "Didelio kontrasto veiksena",
    "Enable high contrast mode" : "Įjungti didelio kontrasto veikseną",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Didelio kontrasto veiksena, skirta palengvinti jūsų naršymą. Vaizdinė kokybė bus sumažinta, tačiau aiškumas bus padidintas.",
    "Dyslexia font" : "Disleksijos šriftas",
    "Enable dyslexia font" : "Įjungti disleksijos šriftą",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic yra laisvas šriftas, sukurtas sumažinti kai kurias dažniausias disleksijos sukeltas skaitymo klaidas.",
    "Accessibility" : "Prieinamumas",
    "Accessibility options for nextcloud" : "Nextcloud prieinamumo parinktys",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Pateikia kelias prieinamumo parinktis, skirtas palengvinti jūsų naudojimąsi Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Mums universalioji prieiga yra labai svarbi. Mes sekame saityno standartus ir stengiamės, kad viskuo galima būtų praktiškai pasinaudoti be pelės ir pagalbinės programinės įrangos, tokios kaip ekrano skaitytuvė. Stengiamės atitikti {guidelines}Saityno turinio prieinamumo gairėms{linkend} 2.1 pagal AA lygmenį, o su didelio kontrasto apipavidalinimu netgi pagal AAA lygmenį.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Jei rasite kokių nors problemų, nesivaržykite apie jas pranešti {issuetracker}mūsų klaidų sekiklyje{linkend}. O jei norite įsitraukti, prisijunkite prie {designteam}mūsų dizaino komandos{linkend}!",
    "High contrast theme" : "Didelio kontrasto apipavidalinimas",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Didelio kontrasto apipavidalinimas, skirtas palengvinti jūsų naršymą. Vaizdinė kokybė bus sumažinta, tačiau aiškumas bus padidintas.",
    "Web Content Accessibility Guidelines" : "Saityno turinio prieinamumo gairėms",
    "our issue tracker" : "mūsų klaidų sekiklyje",
    "our design team" : "mūsų dizaino komanda",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines} 2.1 on AA level, with the high contrast theme even on AAA level." : "Mums universalioji prieiga yra labai svarbi. Mes sekame saityno standartus ir stengiamės, kad viskuo galima būtų praktiškai pasinaudoti be pelės ir pagalbinės programinės įrangos, tokios kaip ekrano skaitytuvė. Stengiamės atitikti {guidelines} 2.1 pagal AA lygmenį, o su didelio kontrasto apipavidalinimu netgi pagal AAA lygmenį.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}. And if you want to get involved, come join {designteam}!" : "Jei rasite kokių nors problemų, nesivaržykite apie jas pranešti {issuetracker}. O jei norite įsitraukti, prisijunkite prie {designteam}!",
    "Enable" : "Įjungti"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
